==> libreoffice-24.2.3.2.tar.xz: libreoffice-24.2.3.2/vcl/inc/osx/salnsmenu.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#ifndef INCLUDED_VCL_INC_OSX_SALNSMENU_H
#define INCLUDED_VCL_INC_OSX_SALNSMENU_H

class AquaSalMenu;
class AquaSalMenuItem;

@interface OOStatusItemView : NSView
{
}
- (void)drawRect:(NSRect)aRect;
- (void)layout;
- (void)mouseUp:(NSEvent*)pEvent;
@end

@interface SalNSMenu : NSMenu
{
    AquaSalMenu* mpMenu;
}
+ (BOOL)dispatchSpecialKeyEquivalents:(NSEvent*)pEvent;
- (id)initWithMenu:(AquaSalMenu*)pMenu;
- (void)menuNeedsUpdate:(NSMenu*)pMenu;
- (void)setSalMenu:(AquaSalMenu*)pMenu;
@end

@interface SalNSMenuItem : NSMenuItem <NSMenuItemValidation>
{
    AquaSalMenuItem* mpMenuItem;
}
- (id)initWithMenuItem:(AquaSalMenuItem*)pMenuItem;
- (void)menuItemTriggered:(id)aSender;
- (BOOL)validateMenuItem:(NSMenuItem*)pMenuItem;
@end

@interface SalNSMainMenu : NSMenu
{
}
- (BOOL)performKeyEquivalent:(NSEvent*)pEvent;
@end

#endif // INCLUDED_VCL_INC_OSX_SALNSMENU_H

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_25.2.7.orig.tar.xz: libreoffice-25.2.7.2/vcl/inc/osx/salnsmenu.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#ifndef INCLUDED_VCL_INC_OSX_SALNSMENU_H
#define INCLUDED_VCL_INC_OSX_SALNSMENU_H

class AquaSalMenu;
class AquaSalMenuItem;

@interface OOStatusItemView : NSView
{
}
- (void)drawRect:(NSRect)aRect;
- (void)layout;
- (void)mouseUp:(NSEvent*)pEvent;
@end

@interface SalNSMenu : NSMenu
{
    AquaSalMenu* mpMenu;
}
+ (BOOL)dispatchSpecialKeyEquivalents:(NSEvent*)pEvent;
- (id)initWithMenu:(AquaSalMenu*)pMenu;
- (void)menuNeedsUpdate:(NSMenu*)pMenu;
- (void)setSalMenu:(AquaSalMenu*)pMenu;
@end

@interface SalNSMenuItem : NSMenuItem <NSMenuItemValidation>
{
    AquaSalMenuItem* mpMenuItem;
    BOOL mbReallyEnabled;
}
- (id)initWithMenuItem:(AquaSalMenuItem*)pMenuItem;
- (BOOL)isReallyEnabled;
- (void)menuItemTriggered:(id)aSender;
- (BOOL)validateMenuItem:(NSMenuItem*)pMenuItem;
- (void)setReallyEnabled:(BOOL)bEnabled;
@end

@interface SalNSMainMenu : NSMenu
{
    NSEvent* mpLastPerformKeyEquivalentEvent;
}
- (id)initWithTitle:(NSString*)pTitle;
- (void)dealloc;
- (BOOL)performKeyEquivalent:(NSEvent*)pEvent;
@end

#endif // INCLUDED_VCL_INC_OSX_SALNSMENU_H

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
